---
title: <span class="badge builder"></span> RoleBindingSubject
---
# <span class="badge builder"></span> RoleBindingSubject

## Constructor

```python
RoleBindingSubject()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> rolebinding.RoleBindingSubject
```

### <span class="badge object-method"></span> kind

```python
def kind(kind: typing.Literal["Team", "User"]) -> typing.Self
```

### <span class="badge object-method"></span> name

The team/user identifier name

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [RoleBindingSubject](./object-RoleBindingSubject.md)
